==> azan-14-atm-machine-1.0.1.tgz: package/main.js <==
#!/usr/bin/env node
import inquirer from "inquirer";
let myBalance = 20000;
let mypin = 2221;
console.log(`Your current balance is : ${myBalance}rs`);
// checking if user enter a correct pin
while (true) {
    let checkMyPin = await inquirer.prompt([
        {
            message: "Please enter your 4 digits pin : ",
            type: "number",
            name: "pin",
        },
    ]);
    if (checkMyPin.pin == mypin) {
        console.log("correct pin");
        //asking user what he wants to do
        let answer = await inquirer.prompt([
            {
                message: "Please select any option",
                name: "option",
                type: "list",
                choices: ["cash withdraw", "withdraw 5k", "withdraw 10k", "withdraw 15k", "check balance"]
            }
        ]);
        //opt 1
        if (answer.option === "cash withdraw") {
            let cash = await inquirer.prompt([
                {
                    message: "Please enter the cash you want to with drawn : ",
                    name: "amount",
                    type: "number"
                }
            ]);
            // checking if user enter amount within the limit or not
            if (cash.amount <= myBalance) {
                console.log(`\nYou have successfully with drawn ${cash.amount}\n`);
                myBalance -= cash.amount;
                console.log(`Now your current balance is ${myBalance}rs`);
            }
            else {
                console.log(`Please enter a valid amount with in your balance limit`);
            }
            // opt2
        }
        else if (answer.option === "withdraw 5k") {
            console.log(`\nyou have successfully withdrawn ${5000}rs\n`);
            myBalance -= 5000;
            console.log(`Now your current balance is ${myBalance}`);
            //opt3
        }
        else if (answer.option === "withdraw 10k") {
            console.log(`\nyou have successfully withdrawn ${10000}rs\n`);
            myBalance -= 10000;
            console.log(`Now your current balance is ${myBalance}`);
            //opt4
        }
        else if (answer.option === "withdraw 15k") {
            console.log(`\nyou have successfully withdrawn ${15000}rs\n`);
            myBalance -= 15000;
            console.log(`Now your current balance is ${myBalance}`);
            //opt5
        }
        else if (answer.option === "check balance") {
            console.log(`Your balance is ${myBalance}rs`);
        }
        break;
    }
    else if (checkMyPin.pin !== mypin) {
        console.log("Incorrect pin please try again");
    }
}

==> azan-14-atm-machine-2.0.3.tgz: package/main.js <==
#!/usr/bin/env node
import inquirer from "inquirer";
let myBalance = 20000;
let mypin = 2221;
console.log(`Your current balance is : ${myBalance}rs`);
// checking if user enter a correct pin
while (true) {
    let checkMyPin = await inquirer.prompt([
        {
            message: "Please enter your 4 digits pin : ",
            type: "number",
            name: "pin",
        },
    ]);
    if (checkMyPin.pin == mypin) {
        console.log("correct pin");
        //asking user what he wants to do
        let answer = await inquirer.prompt([
            {
                message: "Please select any option",
                name: "option",
                type: "list",
                choices: ["cash withdraw", "withdraw 5k", "withdraw 10k", "withdraw 15k", "check balance"]
            }
        ]);
        //opt 1
        if (answer.option === "cash withdraw") {
            let cash = await inquirer.prompt([
                {
                    message: "Please enter the cash you want to with drawn : ",
                    name: "amount",
                    type: "number"
                }
            ]);
            // checking if user enter amount within the limit or not
            while (true) {
                if (cash.amount <= myBalance) {
                    console.log(`\nYou have successfully with drawn ${cash.amount}rs\n`);
                    myBalance -= cash.amount;
                    console.log(`Now your current balance is ${myBalance}rs`);
                    break;
                }
                else if (cash.amount > myBalance) {
                    console.log(`Please enter a valid  amount with in your balance limit`);
                    cash = await inquirer.prompt([
                        {
                            message: "Please enter the cash you want to with drawn : ",
                            name: "amount",
                            type: "number"
                        }
                    ]);
                }
            }
            // opt2
        }
        else if (answer.option === "withdraw 5k") {
            console.log(`\nyou have successfully withdrawn ${5000}rs\n`);
            myBalance -= 5000;
            console.log(`Now your current balance is ${myBalance}rs`);
            //opt3
        }
        else if (answer.option === "withdraw 10k") {
            console.log(`\nyou have successfully withdrawn ${10000}rs\n`);
            myBalance -= 10000;
            console.log(`Now your current balance is ${myBalance}rs`);
            //opt4
        }
        else if (answer.option === "withdraw 15k") {
            console.log(`\nyou have successfully withdrawn ${15000}rs\n`);
            myBalance -= 15000;
            console.log(`Now your current balance is ${myBalance}rs`);
            //opt5
        }
        else if (answer.option === "check balance") {
            console.log(`Your balance is ${myBalance}rs`);
        }
        break;
    }
    else if (checkMyPin.pin !== mypin) {
        console.log("Incorrect pin please try again");
    }
}
